==> org.opennms.features.collection.api-20.0.0-20170207.154750-72-sources.jar: org/opennms/netmgt/collection/dto/GenericTypeResourceDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.dto;

import java.util.Objects;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.netmgt.collection.adapters.ResourceTypeMapper;
import org.opennms.netmgt.collection.api.ResourceType;
import org.opennms.netmgt.collection.support.builder.GenericTypeResource;

@XmlRootElement(name = "generic-type-resource")
@XmlAccessorType(XmlAccessType.NONE)
public class GenericTypeResourceDTO {

    @XmlElement(name = "node-level-resource")
    private NodeLevelResourceDTO parent;

    @XmlAttribute(name = "name")
    private String name;

    @XmlAttribute(name = "instance")
    private String instance;

    public GenericTypeResourceDTO() { }

    public GenericTypeResourceDTO(GenericTypeResource resource) {
        parent = new NodeLevelResourceDTO(resource.getParent());
        name = resource.getResourceType().getName();
        instance = resource.getInstance();
    }

    @Override
    public String toString() {
        return String.format("GenericTypeResourceDTO[parent=%s, name=%s, instance=%s]",
                parent, name, instance);
    }

    @Override
    public int hashCode() {
        return Objects.hash(parent, name, instance);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        } else if (obj == null) {
            return false;
        } else if (!(obj instanceof GenericTypeResourceDTO)) {
            return false;
        }
        GenericTypeResourceDTO other = (GenericTypeResourceDTO) obj;
        return Objects.equals(this.parent, other.parent)
                && Objects.equals(this.name, other.name)
                && Objects.equals(this.instance, other.instance);
    }

    public GenericTypeResource toResource() {
        final ResourceType resourceType = ResourceTypeMapper.getInstance().getResourceType(name);
        return new GenericTypeResource(parent.toResource(), resourceType, instance);
    }
}

==> org.opennms.features.collection.api-20.0.0-20170216.175553-86-sources.jar: org/opennms/netmgt/collection/dto/GenericTypeResourceDTO.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collection.dto;

import java.util.Date;
import java.util.Objects;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.netmgt.collection.adapters.ResourceTypeMapper;
import org.opennms.netmgt.collection.api.ResourceType;
import org.opennms.netmgt.collection.support.builder.DeferredGenericTypeResource;
import org.opennms.netmgt.collection.support.builder.GenericTypeResource;

@XmlRootElement(name = "generic-type-resource")
@XmlAccessorType(XmlAccessType.NONE)
public class GenericTypeResourceDTO {

    @XmlElement(name = "node-level-resource")
    private NodeLevelResourceDTO parent;

    @XmlAttribute(name = "name")
    private String name;

    @XmlAttribute(name = "instance")
    private String instance;

    @XmlAttribute(name = "timestamp")
    private Date timestamp;

    public GenericTypeResourceDTO() { }

    public GenericTypeResourceDTO(DeferredGenericTypeResource resource) {
        parent = new NodeLevelResourceDTO(resource.getParent());
        name = resource.getTypeName();
        instance = resource.getInstance();
        timestamp = resource.getTimestamp();
    }

    @Override
    public String toString() {
        return String.format("GenericTypeResourceDTO[parent=%s, name=%s, instance=%s]",
                parent, name, instance);
    }

    @Override
    public int hashCode() {
        return Objects.hash(parent, name, instance, timestamp);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        } else if (obj == null) {
            return false;
        } else if (!(obj instanceof GenericTypeResourceDTO)) {
            return false;
        }
        GenericTypeResourceDTO other = (GenericTypeResourceDTO) obj;
        return Objects.equals(this.parent, other.parent)
                && Objects.equals(this.name, other.name)
                && Objects.equals(this.instance, other.instance)
                && Objects.equals(this.timestamp, other.timestamp);
    }

    public GenericTypeResource toResource() {
        final ResourceType resourceType = ResourceTypeMapper.getInstance().getResourceType(name);
        final GenericTypeResource resource = new GenericTypeResource(parent.toResource(), resourceType, instance);
        resource.setTimestamp(timestamp);
        return resource;
    }
}
